You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@uima.apache.org by al...@apache.org on 2007/01/12 20:30:31 UTC

svn commit: r495695 - in /incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima: analysis_component/ analysis_engine/ analysis_engine/asb/impl/ analysis_engine/impl/compatibility/ cas/ cas/impl/ cas_data/impl/ jcas/ resource/ uimacpp/ util/

Author: alally
Date: Fri Jan 12 11:30:30 2007
New Revision: 495695

URL: http://svn.apache.org/viewvc?view=rev&rev=495695
Log:
Cleaning up after TCAS removal.
UIMA-115: http://issues.apache.org/jira/browse/UIMA-115

Modified:
    incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/analysis_component/AnalysisComponent.java
    incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/analysis_engine/ResultSpecification.java
    incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/analysis_engine/asb/impl/ASB_impl.java
    incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/analysis_engine/impl/compatibility/AnnotatorAdapter.java
    incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/analysis_engine/impl/compatibility/CasConsumerAdapter.java
    incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/analysis_engine/impl/compatibility/CollectionReaderAdapter.java
    incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/cas/CAS.java
    incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/cas/FeatureStructure.java
    incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/cas/impl/XCASDeserializer.java
    incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/cas/impl/XmiCasDeserializer.java
    incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/cas_data/impl/XCasToCasDataSaxHandler.java
    incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/jcas/JCas.java
    incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/resource/CasManager.java
    incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/uimacpp/CppUimajEngine.java
    incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/util/ConsumerCasUtils.java
    incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/util/JCasPool.java

Modified: incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/analysis_component/AnalysisComponent.java
URL: http://svn.apache.org/viewvc/incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/analysis_component/AnalysisComponent.java?view=diff&rev=495695&r1=495694&r2=495695
==============================================================================
--- incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/analysis_component/AnalysisComponent.java (original)
+++ incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/analysis_component/AnalysisComponent.java Fri Jan 12 11:30:30 2007
@@ -37,11 +37,8 @@
  * <ul>
  * <li> Annotator: Receives an input CAS and updates it
  * <ul>
- * <li>{@link org.apache.uima.analysis_engine.annotator.JTextAnnotator_ImplBase}: Uses JCas
- * interface</li>
- * <li>{@link org.apache.uima.analysis_engine.annotator.TextAnnotator}: Uses CAS interface</li>
- * <li>{@link org.apache.uima.analysis_engine.annotator.GenericAnnotator_ImplBase}: Uses CAS
- * interface
+ * <li>{@link JCasAnnotator_ImplBase}: Uses JCas interface</li>
+ * <li>{@link CasAnnotator_ImplBase}: Uses CASinterface
  * </ul>
  * </li>
  * <li>{@link org.apache.uima.collection.CasConsumer_ImplBase}: Receives an input CAS but does not

Modified: incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/analysis_engine/ResultSpecification.java
URL: http://svn.apache.org/viewvc/incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/analysis_engine/ResultSpecification.java?view=diff&rev=495695&r1=495694&r2=495695
==============================================================================
--- incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/analysis_engine/asb/impl/ASB_impl.java (original)
+++ incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/analysis_engine/asb/impl/ASB_impl.java Fri Jan 12 11:30:30 2007
@@ -210,7 +210,7 @@
           // the mapping is for this analysis engine
           if (mSofaMappings[s].getComponentKey().equals(key)) {
             // if component sofa name is null, replace it with the default for CAS sofa name
-            // This is to support old style CAS
+            // This is to support single-view annotators.
             if (mSofaMappings[s].getComponentSofaName() == null)
               mSofaMappings[s].setComponentSofaName(CAS.NAME_DEFAULT_TEXT_SOFA);
             sofamap.put(mSofaMappings[s].getComponentSofaName(), mSofaMappings[s]
@@ -281,8 +281,8 @@
       for (int s = 0; s < mSofaMappings.length; s++) {
         // the mapping is for this analysis engine
         if (mSofaMappings[s].getComponentKey().equals(key)) {
-          // if component sofa name is null, replace it with the default for CAS sofa name
-          // This is to support old style CAS
+          // if component sofa name is null, replace it with the default for TCAS sofa name
+          // This is to support single-view annotators.
           if (mSofaMappings[s].getComponentSofaName() == null)
             mSofaMappings[s].setComponentSofaName(CAS.NAME_DEFAULT_TEXT_SOFA);
           sofamap.put(mSofaMappings[s].getComponentSofaName(), mSofaMappings[s]

Modified: incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/analysis_engine/impl/compatibility/AnnotatorAdapter.java
URL: http://svn.apache.org/viewvc/incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/analysis_engine/impl/compatibility/AnnotatorAdapter.java?view=diff&rev=495695&r1=495694&r2=495695
==============================================================================
--- incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/analysis_engine/impl/compatibility/AnnotatorAdapter.java (original)
+++ incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/analysis_engine/impl/compatibility/AnnotatorAdapter.java Fri Jan 12 11:30:30 2007
@@ -136,9 +136,9 @@
     // do proper typecasts and call process method
     try {
       if (mAnnotator instanceof TextAnnotator) {
-        CAS tcas = (CAS) aCAS;
-        ResultSpecification rs = getResultSpecForLanguage(tcas.getDocumentLanguage());
-        ((TextAnnotator) mAnnotator).process(tcas, rs);
+        CAS cas = (CAS) aCAS;
+        ResultSpecification rs = getResultSpecForLanguage(cas.getDocumentLanguage());
+        ((TextAnnotator) mAnnotator).process(cas, rs);
       } else if (mAnnotator instanceof JTextAnnotator) {
         JCas jcas = (JCas) aCAS;
         ResultSpecification rs = getResultSpecForLanguage(jcas.getDocumentLanguage());
@@ -185,7 +185,7 @@
       TypeSystem typeSystem;
       if (aCAS instanceof JCas) {
         typeSystem = ((JCas) aCAS).getTypeSystem();
-      } else // CAS or CAS
+      } else // CAS 
       {
         typeSystem = ((CAS) aCAS).getTypeSystem();
       }

Modified: incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/analysis_engine/impl/compatibility/CasConsumerAdapter.java
URL: http://svn.apache.org/viewvc/incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/analysis_engine/impl/compatibility/CasConsumerAdapter.java?view=diff&rev=495695&r1=495694&r2=495695
==============================================================================
--- incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/analysis_engine/impl/compatibility/CasConsumerAdapter.java (original)
+++ incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/analysis_engine/impl/compatibility/CasConsumerAdapter.java Fri Jan 12 11:30:30 2007
@@ -112,7 +112,7 @@
       TypeSystem typeSystem;
       if (aCAS instanceof JCas) {
         typeSystem = ((JCas) aCAS).getTypeSystem();
-      } else // CAS or CAS
+      } else // CAS 
       {
         typeSystem = ((CAS) aCAS).getTypeSystem();
       }

Modified: incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/analysis_engine/impl/compatibility/CollectionReaderAdapter.java
URL: http://svn.apache.org/viewvc/incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/analysis_engine/impl/compatibility/CollectionReaderAdapter.java?view=diff&rev=495695&r1=495694&r2=495695
==============================================================================
--- incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/analysis_engine/impl/compatibility/CollectionReaderAdapter.java (original)
+++ incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/analysis_engine/impl/compatibility/CollectionReaderAdapter.java Fri Jan 12 11:30:30 2007
@@ -95,7 +95,7 @@
       TypeSystem typeSystem;
       if (aCAS instanceof JCas) {
         typeSystem = ((JCas) aCAS).getTypeSystem();
-      } else // CAS or CAS
+      } else // CAS
       {
         typeSystem = ((CAS) aCAS).getTypeSystem();
       }

Modified: incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/cas/CAS.java
URL: http://svn.apache.org/viewvc/incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/cas/CAS.java?view=diff&rev=495695&r1=495694&r2=495695
==============================================================================
--- incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/cas/CAS.java (original)
+++ incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/cas/CAS.java Fri Jan 12 11:30:30 2007
@@ -397,7 +397,7 @@
           + TypeSystem.FEATURE_SEPARATOR + FEATURE_BASE_NAME_TAIL;
 
   /**
-   * Name of CAS (Text CAS) name space.
+   * Name of Text CAS name space.
    */
   static final String NAME_SPACE_UIMA_TCAS = "uima" + TypeSystem.NAMESPACE_SEPARATOR + "tcas";
 
@@ -458,8 +458,7 @@
           + TypeSystem.FEATURE_SEPARATOR + FEATURE_BASE_NAME_LANGUAGE;
 
   /**
-   * Name of the standard index on annotations. The standard index is automatically defined if you
-   * use a CAS.
+   * Name of the built-in index on annotations.
    */
   static final String STD_ANNOTATION_INDEX = "AnnotationIndex";
 
@@ -563,9 +562,10 @@
   JCas getJCas() throws CASException;
 
   /**
-   * Get the Cas view specified for the current component.
+   * Get the Cas view that the current component should use.  This
+   * should only be used by single-view components.
    * 
-   * @return the Cas view specified for the current component by Sofa mapping. Defaults to _InitialView.
+   * @return the Cas view specified for the current component by Sofa mapping. Defaults to _InitialView if there is no Sofa mapping.
    * 
    */
   CAS getCurrentView();
@@ -583,7 +583,7 @@
   /**
    * Get the Sofa feature structure associated with this CAS view.
    * 
-   * @return The SofaFS associated with this CAS.
+   * @return The SofaFS associated with this CAS view.
    */
   SofaFS getSofa();
 

Modified: incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/cas/FeatureStructure.java
URL: http://svn.apache.org/viewvc/incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/cas/FeatureStructure.java?view=diff&rev=495695&r1=495694&r2=495695
==============================================================================
--- incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/cas/FeatureStructure.java (original)
+++ incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/cas/FeatureStructure.java Fri Jan 12 11:30:30 2007
@@ -261,7 +261,7 @@
    * 
    * @param feat.
    *          The feature whose value we want to get and whose type is one of the primitve types.
-   * @return A string representation of a primitive feature value.
+   * @return
    * @throws CASRuntimeException
    *           If <code>feat</code> is not defined for the type of this FS, or if the type is not
    *           a primitive type.

Modified: incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/cas/impl/XCASDeserializer.java
URL: http://svn.apache.org/viewvc/incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/cas/impl/XCASDeserializer.java?view=diff&rev=495695&r1=495694&r2=495695
==============================================================================
--- incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/cas_data/impl/XCasToCasDataSaxHandler.java (original)
+++ incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/cas_data/impl/XCasToCasDataSaxHandler.java Fri Jan 12 11:30:30 2007
@@ -44,8 +44,7 @@
   // Expect the start of the XML document.
   private static final int DOC_STATE = 0;
 
-  // At the top level. Expect a FS, or a CAS document, or the end of the
-  // XML input.
+  // At the top level. Expect a FS.
   private static final int FS_STATE = 1;
 
   // Inside a FS. Expect features, or the end of the FS.
@@ -63,9 +62,6 @@
   // Inside an array FS. Expect an array element, or the end of the FS.
   private static final int ARRAY_ELE_STATE = 6;
 
-  // Inside the CAS document. Expect the doc text.
-  private static final int DOC_TEXT_STATE = 7;
-
   // End parser states.
   // ///////////////////////////////////////////////////////////////////////
 
@@ -340,7 +336,7 @@
    * @see org.xml.sax.ContentHandler#characters(char[], int, int)
    */
   public void characters(char[] chars, int start, int length) throws SAXException {
-    if ((this.state == DOC_TEXT_STATE) || (this.state == CONTENT_STATE)
+    if ((this.state == CONTENT_STATE)
             || (this.state == ARRAY_ELE_CONTENT_STATE) || (this.state == FEAT_CONTENT_STATE)) {
       // When we're in a text expecting state, add the characters to the
       // text buffer. Else, do nothing.

Modified: incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/jcas/JCas.java
URL: http://svn.apache.org/viewvc/incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/jcas/JCas.java?view=diff&rev=495695&r1=495694&r2=495695
==============================================================================
--- incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/jcas/JCas.java (original)
+++ incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/jcas/JCas.java Fri Jan 12 11:30:30 2007
@@ -174,7 +174,7 @@
    * the framework ClassLoader.
    * 
    * @return The one instance of the DocumentAnnotation annotation.
-   * @see org.apache.uima.cas.text.CAS#getDocumentAnnotation
+   * @see org.apache.uima.cas.CAS#getDocumentAnnotation
    */
   public abstract TOP getDocumentAnnotationFs();
 

Modified: incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/resource/CasManager.java
URL: http://svn.apache.org/viewvc/incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/resource/CasManager.java?view=diff&rev=495695&r1=495694&r2=495695
==============================================================================
--- incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/resource/CasManager.java (original)
+++ incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/resource/CasManager.java Fri Jan 12 11:30:30 2007
@@ -86,7 +86,7 @@
    * @param cas
    *          The CAS
    * @param requiredInterface
-   *          interface to get. Currently must be one of CAS, CAS, or JCas.
+   *          interface to get. Currently must be either CAS or JCas.
    */
   AbstractCas getCasInterface(CAS cas, Class requiredInterface);
 }

Modified: incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/uimacpp/CppUimajEngine.java
URL: http://svn.apache.org/viewvc/incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/uimacpp/CppUimajEngine.java?view=diff&rev=495695&r1=495694&r2=495695
==============================================================================
--- incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/uimacpp/CppUimajEngine.java (original)
+++ incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/uimacpp/CppUimajEngine.java Fri Jan 12 11:30:30 2007
@@ -209,10 +209,10 @@
         // 3. call process with tcas or cas
         if (requiresTCas && sofaNum == 0) {
           result = 1;
-          exceptionString = "This CasConsumer expects a CAS but Sofa from which to construct one is not specified.";
+          exceptionString = "This CasConsumer expects a View, but the Sofa from which to construct one is not specified.";
         } else if (sofaNum > 0) {
-          CAS tcas = casImpl.getView(sofaNum);
-          cc.processCas(tcas);
+          CAS view = casImpl.getView(sofaNum);
+          cc.processCas(view);
         } else {
           cc.processCas(casImpl);
         }

Modified: incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/util/ConsumerCasUtils.java
URL: http://svn.apache.org/viewvc/incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/util/ConsumerCasUtils.java?view=diff&rev=495695&r1=495694&r2=495695
==============================================================================
--- incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/util/ConsumerCasUtils.java (original)
+++ incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/util/ConsumerCasUtils.java Fri Jan 12 11:30:30 2007
@@ -25,29 +25,29 @@
 import org.apache.uima.cas.Type;
 
 public class ConsumerCasUtils {
-  public static int getIntFeatValue(CAS aTcas, String aTypeS, String aFeatS) {
+  public static int getIntFeatValue(CAS aCasView, String aTypeS, String aFeatS) {
     int result = 0;
-    Type type = aTcas.getTypeSystem().getType(aTypeS);
+    Type type = aCasView.getTypeSystem().getType(aTypeS);
     if (type != null) {
-      FSIterator idIter = aTcas.getAnnotationIndex(type).iterator();
+      FSIterator idIter = aCasView.getAnnotationIndex(type).iterator();
       while (idIter.isValid()) {
         org.apache.uima.cas.FeatureStructure idFS = idIter.get();
         result = idFS
-                .getIntValue(aTcas.getTypeSystem().getFeatureByFullName(aTypeS + ":" + aFeatS));
+                .getIntValue(aCasView.getTypeSystem().getFeatureByFullName(aTypeS + ":" + aFeatS));
         idIter.moveToNext();
       }
     }
     return result;
   }
 
-  public static String getStringFeatValue(CAS aTcas, String aTypeS, String aFeatS) {
+  public static String getStringFeatValue(CAS aCasView, String aTypeS, String aFeatS) {
     String result = null;
-    Type type = aTcas.getTypeSystem().getType(aTypeS);
+    Type type = aCasView.getTypeSystem().getType(aTypeS);
     if (type != null) {
-      FSIterator idIter = aTcas.getAnnotationIndex(type).iterator();
+      FSIterator idIter = aCasView.getAnnotationIndex(type).iterator();
       while (idIter.isValid()) {
         org.apache.uima.cas.FeatureStructure idFS = idIter.get();
-        result = idFS.getStringValue(aTcas.getTypeSystem().getFeatureByFullName(
+        result = idFS.getStringValue(aCasView.getTypeSystem().getFeatureByFullName(
                 aTypeS + ":" + aFeatS));
         idIter.moveToNext();
       }
@@ -55,11 +55,11 @@
     return result;
   }
 
-  public static FeatureStructure getTcasFS(CAS aTcas, String aTypeS) {
+  public static FeatureStructure getTcasFS(CAS aCasView, String aTypeS) {
     org.apache.uima.cas.FeatureStructure idFS = null;
-    Type type = aTcas.getTypeSystem().getType(aTypeS);
+    Type type = aCasView.getTypeSystem().getType(aTypeS);
     if (type != null) {
-      FSIterator idIter = aTcas.getAnnotationIndex(type).iterator();
+      FSIterator idIter = aCasView.getAnnotationIndex(type).iterator();
       while (idIter.isValid()) {
         idFS = idIter.get();
         idIter.moveToNext();

Modified: incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/util/JCasPool.java
URL: http://svn.apache.org/viewvc/incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/util/JCasPool.java?view=diff&rev=495695&r1=495694&r2=495695
==============================================================================
--- incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/util/JCasPool.java (original)
+++ incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/util/JCasPool.java Fri Jan 12 11:30:30 2007
@@ -106,7 +106,7 @@
    * Creates a new JCasPool
    * 
    * @param aNumInstances
-   *          the number of CAS instances in the pool
+   *          the number of JCas instances in the pool
    * @param aMetaData
    *          metadata that includes the type system for the CAS
    *
--- incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/analysis_engine/ResultSpecification.java (original)
+++ incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/analysis_engine/ResultSpecification.java Fri Jan 12 11:30:30 2007
@@ -21,6 +21,7 @@
 
 import java.io.Serializable;
 
+import org.apache.uima.analysis_component.AnalysisComponent;
 import org.apache.uima.cas.CAS;
 import org.apache.uima.cas.TypeSystem;
 import org.apache.uima.resource.metadata.Capability;
@@ -31,14 +32,12 @@
  * Annotator. Each output is a reference to either a {@link org.apache.uima.cas.Type} or a
  * {@link org.apache.uima.cas.Feature}.
  * <p>
  * Annotator implementations are expected to only produce those <code>Type</code>s and
  * <code>Feature</code>s that are part of the <code>ResultSpecification</code> passed as a
  * parameter to their
  * {@link org.apache.uima.analysis_engine.annotator.TextAnnotator#process(CAS,ResultSpecification)}
  * method. Annotators can call the {@link #containsType(String)} and
  * {@link #containsFeature(String)} to determine which types and features belong to this
  * ResultSpecification and should be produced.
- * 
  * <p>
  * ResultSpecifications are language enabled to allow different values to be set and returned, based
  * on a ISO language identifier. There are two styles of the get and add methods: one takes an
@@ -31,14 +32,12 @@
  * {@link org.apache.uima.cas.Feature}.
  * <p>
- * Annotator implementations are expected to only produce those <code>Type</code>s and
- * <code>Feature</code>s that are part of the <code>ResultSpecification</code> passed as a
- * parameter to their
- * {@link org.apache.uima.analysis_engine.annotator.TextAnnotator#process(CAS,ResultSpecification)}
- * method. Annotators can call the {@link #containsType(String)} and
+ * Annotator implementations may, but are not required to, check the <code>ResultSpecification</code> 
+ * passed as a parameter to their {@link AnalysisComponent#setResultSpecification(ResultSpecification)}},
+ * and produce only those <code>Type</code>s and <code>Feature</code>s that are part of the 
+ * ResultSpecification.  Annotators can call the {@link #containsType(String)} and
  * {@link #containsFeature(String)} to determine which types and features belong to this
  * ResultSpecification and should be produced.

Modified: incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/analysis_engine/asb/impl/ASB_impl.java
URL: http://svn.apache.org/viewvc/incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/analysis_engine/asb/impl/ASB_impl.java?view=diff&rev=495695&r1=495694&r2=495695
==============================================================================
--- incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/cas/impl/XCASDeserializer.java (original)
+++ incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/cas/impl/XCASDeserializer.java Fri Jan 12 11:30:30 2007
@@ -73,7 +73,7 @@
     // Expect the start of the XML document.
     private static final int DOC_STATE = 0;
 
-    // At the top level. Expect a FS, or a CAS document, or the end of the
+    // At the top level. Expect a FS, or the document text element, or the end of the
     // XML input.
     private static final int FS_STATE = 1;
 
@@ -92,7 +92,7 @@
     // Inside an array FS. Expect an array element, or the end of the FS.
     private static final int ARRAY_ELE_STATE = 6;
 
-    // Inside the CAS document. Expect the doc text.
+    // Inside the document text element. Expect the doc text.
     private static final int DOC_TEXT_STATE = 7;
 
     // Inside an Out-Of-Typesystem FS. Expect features, or the end of the FS.
@@ -159,8 +159,8 @@
     // Store IndexRepositories in a vector;
     private ArrayList indexRepositories;
 
-    // and CAS too
-    private ArrayList tcasInstances;
+    // and Views too
+    private ArrayList views;
 
     // for processing v1.x format XCAS
     // map from sofa int values to id references
@@ -182,7 +182,7 @@
       this.buffer = new StringBuffer();
       this.outOfTypeSystemData = ootsData;
       this.indexRepositories = new ArrayList();
-      this.tcasInstances = new ArrayList();
+      this.views = new ArrayList();
       // using the baseCas for indexing Sofas
       indexRepositories.add(this.cas.getBaseIndexRepository());
       // There should always be another index for the Initial View
@@ -462,7 +462,7 @@
           indexRepositories.add(cas.getSofaIndexRepository(sofa));
         }
         ((CASImpl) view).registerView(sofa);
-        tcasInstances.add(view);
+        views.add(view);
       }
       FSInfo fsInfo = new FSInfo(addr, indexRep);
       if (id < 0) {
@@ -780,8 +780,8 @@
         finalizeOutOfTypeSystemFeatures();
       }
 
-      for (int i = 0; i < tcasInstances.size(); i++) {
-        ((CASImpl) tcasInstances.get(i)).updateDocumentAnnotation();
+      for (int i = 0; i < views.size(); i++) {
+        ((CASImpl) views.get(i)).updateDocumentAnnotation();
       }
     }
 

Modified: incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/cas/impl/XmiCasDeserializer.java
URL: http://svn.apache.org/viewvc/incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/cas/impl/XmiCasDeserializer.java?view=diff&rev=495695&r1=495694&r2=495695
==============================================================================
--- incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/cas/impl/XmiCasDeserializer.java (original)
+++ incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/cas/impl/XmiCasDeserializer.java Fri Jan 12 11:30:30 2007
@@ -69,7 +69,7 @@
     // Expect the start of the XML document.
     private static final int DOC_STATE = 0;
 
-    // At the top level. Expect a FS, or a CAS document, or the end of the
+    // At the top level. Expect a FS, or document text element, or the end of the
     // XML input.
     private static final int FS_STATE = 1;
 
@@ -148,8 +148,8 @@
     // Store IndexRepositories in a vector;
     private ArrayList indexRepositories;
 
-    // and CAS too
-    private ArrayList tcasInstances;
+    // and views too
+    private ArrayList views;
 
     // utilities for handling CAS list types
     private ListUtils listUtils;
@@ -187,7 +187,7 @@
       this.fsListNodesFromMultivaluedProperties = new IntVector();
       this.buffer = new StringBuffer();
       this.indexRepositories = new ArrayList();
-      this.tcasInstances = new ArrayList();
+      this.views = new ArrayList();
       indexRepositories.add(this.cas.getBaseIndexRepository());
       // There should always be another index for the Initial View
       indexRepositories.add(this.cas.getView(CAS.NAME_DEFAULT_SOFA).getIndexRepository());
@@ -449,7 +449,7 @@
           indexRepositories.add(cas.getSofaIndexRepository(sofa));
         }
         ((CASImpl) view).registerView(sofa);
-        tcasInstances.add(view);
+        views.add(view);
       }
       if (id < 0) {
         idLess.add(addr);
@@ -930,8 +930,8 @@
       // time = System.currentTimeMillis() - time;
       // System.out.println("Done in " + new TimeSpan(time));
 
-      for (int i = 0; i < tcasInstances.size(); i++) {
-        ((CASImpl) tcasInstances.get(i)).updateDocumentAnnotation();
+      for (int i = 0; i < views.size(); i++) {
+        ((CASImpl) views.get(i)).updateDocumentAnnotation();
       }
     }
 

Modified: incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/cas_data/impl/XCasToCasDataSaxHandler.java
URL: http://svn.apache.org/viewvc/incubator/uima/uimaj/trunk/uimaj-core/src/main/java/org/apache/uima/cas_data/impl/XCasToCasDataSaxHandler.java?view=diff&rev=495695&r1=495694&r2=495695
==============================================================================